@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Urls"""
 
-from django.conf.urls.defaults import patterns, url
+from .compat import patterns, url
 from django_states.views import make_state_transition
 
 urlpatterns = patterns('',
